Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(741)

Unified Diff: talk/app/webrtc/statstypes.h

Issue 1362503003: Use suffixed {uint,int}{8,16,32,64}_t types. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: rebase + revert basictypes.h (to be landed separately just in case of a revert due to unexpected us… Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « talk/app/webrtc/statscollector_unittest.cc ('k') | talk/app/webrtc/statstypes.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: talk/app/webrtc/statstypes.h
diff --git a/talk/app/webrtc/statstypes.h b/talk/app/webrtc/statstypes.h
index 33b2fa74101e1ba5095f2d89ed12659bea3adf8f..7fa9f3212d030305d52d9b01328ef93157d9f29b 100644
--- a/talk/app/webrtc/statstypes.h
+++ b/talk/app/webrtc/statstypes.h
@@ -250,16 +250,16 @@ class StatsReport {
struct Value {
enum Type {
- kInt, // int.
- kInt64, // int64.
- kFloat, // float.
- kString, // std::string
+ kInt, // int.
+ kInt64, // int64_t.
+ kFloat, // float.
+ kString, // std::string
kStaticString, // const char*.
- kBool, // bool.
- kId, // Id.
+ kBool, // bool.
+ kId, // Id.
};
- Value(StatsValueName name, int64 value, Type int_type);
+ Value(StatsValueName name, int64_t value, Type int_type);
Value(StatsValueName name, float f);
Value(StatsValueName name, const std::string& value);
Value(StatsValueName name, const char* value);
@@ -281,7 +281,7 @@ class StatsReport {
// kString and kStaticString too.
bool operator==(const std::string& value) const;
bool operator==(const char* value) const;
- bool operator==(int64 value) const;
+ bool operator==(int64_t value) const;
bool operator==(bool value) const;
bool operator==(float value) const;
bool operator==(const Id& value) const;
@@ -289,7 +289,7 @@ class StatsReport {
// Getters that allow getting the native value directly.
// The caller must know the type beforehand or else hit a check.
int int_val() const;
- int64 int64_val() const;
+ int64_t int64_val() const;
float float_val() const;
const char* static_string_val() const;
const std::string& string_val() const;
@@ -312,7 +312,7 @@ class StatsReport {
// TODO(tommi): Use C++ 11 union and make value_ const.
union InternalType {
int int_;
- int64 int64_;
+ int64_t int64_;
float float_;
bool bool_;
std::string* string_;
@@ -355,7 +355,7 @@ class StatsReport {
void AddString(StatsValueName name, const std::string& value);
void AddString(StatsValueName name, const char* value);
- void AddInt64(StatsValueName name, int64 value);
+ void AddInt64(StatsValueName name, int64_t value);
void AddInt(StatsValueName name, int value);
void AddFloat(StatsValueName name, float value);
void AddBoolean(StatsValueName name, bool value);
« no previous file with comments | « talk/app/webrtc/statscollector_unittest.cc ('k') | talk/app/webrtc/statstypes.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698